# Copyright 2019-present Open Networking Foundation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import absolute_import, print_function
import unittest

from google.api import annotations_pb2
from voltha_protos import voltha_pb2

print("imported api annotations properly")


class TestProtos(unittest.TestCase):

    @classmethod
    def setUpClass(self):
        print("in setup")

    def test_proto_call(self):
        """ initialization """

        image_downloader = voltha_pb2.ImageDownload()

        self.assertIsNotNone(image_downloader)




# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from voltha_protos import afrouter_pb2 as voltha__protos_dot_afrouter__pb2


class ConfigurationStub(object):
    """Missing associated documentation comment in .proto file"""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetConnection = channel.unary_unary(
                '/afrouter.Configuration/SetConnection',
                request_serializer=voltha__protos_dot_afrouter__pb2.Conn.SerializeToString,
                response_deserializer=voltha__protos_dot_afrouter__pb2.Result.FromString,
                )
        self.SetAffinity = channel.unary_unary(
                '/afrouter.Configuration/SetAffinity',
                request_serializer=voltha__protos_dot_afrouter__pb2.Affinity.SerializeToString,
                response_deserializer=voltha__protos_dot_afrouter__pb2.Result.FromString,
                )
        self.GetGoroutineCount = channel.unary_unary(
                '/afrouter.Configuration/GetGoroutineCount',
                request_serializer=voltha__protos_dot_afrouter__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_afrouter__pb2.Count.FromString,
                )


class ConfigurationServicer(object):
    """Missing associated documentation comment in .proto file"""

    def SetConnection(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAffinity(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGoroutineCount(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ConfigurationServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.SetConnection,
                    request_deserializer=voltha__protos_dot_afrouter__pb2.Conn.FromString,
                    response_serializer=voltha__protos_dot_afrouter__pb2.Result.SerializeToString,
            ),
            'SetAffinity': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAffinity,
                    request_deserializer=voltha__protos_dot_afrouter__pb2.Affinity.FromString,
                    response_serializer=voltha__protos_dot_afrouter__pb2.Result.SerializeToString,
            ),
            'GetGoroutineCount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGoroutineCount,
                    request_deserializer=voltha__protos_dot_afrouter__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_afrouter__pb2.Count.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'afrouter.Configuration', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Configuration(object):
    """Missing associated documentation comment in .proto file"""

    @staticmethod
    def SetConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/afrouter.Configuration/SetConnection',
            voltha__protos_dot_afrouter__pb2.Conn.SerializeToString,
            voltha__protos_dot_afrouter__pb2.Result.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAffinity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/afrouter.Configuration/SetAffinity',
            voltha__protos_dot_afrouter__pb2.Affinity.SerializeToString,
            voltha__protos_dot_afrouter__pb2.Result.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGoroutineCount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/afrouter.Configuration/GetGoroutineCount',
            voltha__protos_dot_afrouter__pb2.Empty.SerializeToString,
            voltha__protos_dot_afrouter__pb2.Count.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/afrouter.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/afrouter.proto',
  package='afrouter',
  syntax='proto3',
  serialized_options=b'\n\023org.opencord.volthaZ0github.com/opencord/voltha-protos/v3/go/afrouter',
  serialized_pb=b'\n\x1cvoltha_protos/afrouter.proto\x12\x08\x61\x66router\x1a\x1avoltha_protos/common.proto\"6\n\x06Result\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x0c\n\x04info\x18\x03 \x01(\t\"\x07\n\x05\x45mpty\"\x16\n\x05\x43ount\x12\r\n\x05\x63ount\x18\x01 \x01(\r\"\x82\x01\n\x04\x43onn\x12\x0e\n\x06server\x18\x01 \x01(\t\x12\x0b\n\x03pkg\x18\x02 \x01(\t\x12\x0b\n\x03svc\x18\x03 \x01(\t\x12\x0f\n\x07\x63luster\x18\x04 \x01(\t\x12\x0f\n\x07\x62\x61\x63kend\x18\x05 \x01(\t\x12\x12\n\nconnection\x18\x06 \x01(\t\x12\x0c\n\x04\x61\x64\x64r\x18\x07 \x01(\t\x12\x0c\n\x04port\x18\x08 \x01(\x04\"W\n\x08\x41\x66\x66inity\x12\x0e\n\x06router\x18\x01 \x01(\t\x12\r\n\x05route\x18\x02 \x01(\t\x12\x0f\n\x07\x63luster\x18\x03 \x01(\t\x12\x0f\n\x07\x62\x61\x63kend\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t2\xb4\x01\n\rConfiguration\x12\x33\n\rSetConnection\x12\x0e.afrouter.Conn\x1a\x10.afrouter.Result\"\x00\x12\x35\n\x0bSetAffinity\x12\x12.afrouter.Affinity\x1a\x10.afrouter.Result\"\x00\x12\x37\n\x11GetGoroutineCount\x12\x0f.afrouter.Empty\x1a\x0f.afrouter.Count\"\x00\x42G\n\x13org.opencord.volthaZ0github.com/opencord/voltha-protos/v3/go/afrouterb\x06proto3'
  ,
  dependencies=[voltha__protos_dot_common__pb2.DESCRIPTOR,])




_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='afrouter.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='afrouter.Result.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='afrouter.Result.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info', full_name='afrouter.Result.info', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=124,
)


_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='afrouter.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=133,
)


_COUNT = _descriptor.Descriptor(
  name='Count',
  full_name='afrouter.Count',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='afrouter.Count.count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=157,
)


_CONN = _descriptor.Descriptor(
  name='Conn',
  full_name='afrouter.Conn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server', full_name='afrouter.Conn.server', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pkg', full_name='afrouter.Conn.pkg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='svc', full_name='afrouter.Conn.svc', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='afrouter.Conn.cluster', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='backend', full_name='afrouter.Conn.backend', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connection', full_name='afrouter.Conn.connection', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='addr', full_name='afrouter.Conn.addr', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='afrouter.Conn.port', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=160,
  serialized_end=290,
)


_AFFINITY = _descriptor.Descriptor(
  name='Affinity',
  full_name='afrouter.Affinity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='router', full_name='afrouter.Affinity.router', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='route', full_name='afrouter.Affinity.route', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='afrouter.Affinity.cluster', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='backend', full_name='afrouter.Affinity.backend', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='afrouter.Affinity.id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=292,
  serialized_end=379,
)

DESCRIPTOR.message_types_by_name['Result'] = _RESULT
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
DESCRIPTOR.message_types_by_name['Count'] = _COUNT
DESCRIPTOR.message_types_by_name['Conn'] = _CONN
DESCRIPTOR.message_types_by_name['Affinity'] = _AFFINITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'voltha_protos.afrouter_pb2'
  # @@protoc_insertion_point(class_scope:afrouter.Result)
  })
_sym_db.RegisterMessage(Result)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'voltha_protos.afrouter_pb2'
  # @@protoc_insertion_point(class_scope:afrouter.Empty)
  })
_sym_db.RegisterMessage(Empty)

Count = _reflection.GeneratedProtocolMessageType('Count', (_message.Message,), {
  'DESCRIPTOR' : _COUNT,
  '__module__' : 'voltha_protos.afrouter_pb2'
  # @@protoc_insertion_point(class_scope:afrouter.Count)
  })
_sym_db.RegisterMessage(Count)

Conn = _reflection.GeneratedProtocolMessageType('Conn', (_message.Message,), {
  'DESCRIPTOR' : _CONN,
  '__module__' : 'voltha_protos.afrouter_pb2'
  # @@protoc_insertion_point(class_scope:afrouter.Conn)
  })
_sym_db.RegisterMessage(Conn)

Affinity = _reflection.GeneratedProtocolMessageType('Affinity', (_message.Message,), {
  'DESCRIPTOR' : _AFFINITY,
  '__module__' : 'voltha_protos.afrouter_pb2'
  # @@protoc_insertion_point(class_scope:afrouter.Affinity)
  })
_sym_db.RegisterMessage(Affinity)


DESCRIPTOR._options = None

_CONFIGURATION = _descriptor.ServiceDescriptor(
  name='Configuration',
  full_name='afrouter.Configuration',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=382,
  serialized_end=562,
  methods=[
  _descriptor.MethodDescriptor(
    name='SetConnection',
    full_name='afrouter.Configuration.SetConnection',
    index=0,
    containing_service=None,
    input_type=_CONN,
    output_type=_RESULT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetAffinity',
    full_name='afrouter.Configuration.SetAffinity',
    index=1,
    containing_service=None,
    input_type=_AFFINITY,
    output_type=_RESULT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetGoroutineCount',
    full_name='afrouter.Configuration.GetGoroutineCount',
    index=2,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_COUNT,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONFIGURATION)

DESCRIPTOR.services_by_name['Configuration'] = _CONFIGURATION

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import openolt_pb2 as voltha__protos_dot_openolt__pb2
from voltha_protos import tech_profile_pb2 as voltha__protos_dot_tech__profile__pb2


class OpenoltStub(object):
    """Missing associated documentation comment in .proto file"""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DisableOlt = channel.unary_unary(
                '/openolt.Openolt/DisableOlt',
                request_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.ReenableOlt = channel.unary_unary(
                '/openolt.Openolt/ReenableOlt',
                request_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.ActivateOnu = channel.unary_unary(
                '/openolt.Openolt/ActivateOnu',
                request_serializer=voltha__protos_dot_openolt__pb2.Onu.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.DeactivateOnu = channel.unary_unary(
                '/openolt.Openolt/DeactivateOnu',
                request_serializer=voltha__protos_dot_openolt__pb2.Onu.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.DeleteOnu = channel.unary_unary(
                '/openolt.Openolt/DeleteOnu',
                request_serializer=voltha__protos_dot_openolt__pb2.Onu.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.OmciMsgOut = channel.unary_unary(
                '/openolt.Openolt/OmciMsgOut',
                request_serializer=voltha__protos_dot_openolt__pb2.OmciMsg.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.OnuPacketOut = channel.unary_unary(
                '/openolt.Openolt/OnuPacketOut',
                request_serializer=voltha__protos_dot_openolt__pb2.OnuPacket.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.UplinkPacketOut = channel.unary_unary(
                '/openolt.Openolt/UplinkPacketOut',
                request_serializer=voltha__protos_dot_openolt__pb2.UplinkPacket.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.FlowAdd = channel.unary_unary(
                '/openolt.Openolt/FlowAdd',
                request_serializer=voltha__protos_dot_openolt__pb2.Flow.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.FlowRemove = channel.unary_unary(
                '/openolt.Openolt/FlowRemove',
                request_serializer=voltha__protos_dot_openolt__pb2.Flow.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.HeartbeatCheck = channel.unary_unary(
                '/openolt.Openolt/HeartbeatCheck',
                request_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Heartbeat.FromString,
                )
        self.EnablePonIf = channel.unary_unary(
                '/openolt.Openolt/EnablePonIf',
                request_serializer=voltha__protos_dot_openolt__pb2.Interface.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.DisablePonIf = channel.unary_unary(
                '/openolt.Openolt/DisablePonIf',
                request_serializer=voltha__protos_dot_openolt__pb2.Interface.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.GetDeviceInfo = channel.unary_unary(
                '/openolt.Openolt/GetDeviceInfo',
                request_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.DeviceInfo.FromString,
                )
        self.Reboot = channel.unary_unary(
                '/openolt.Openolt/Reboot',
                request_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.CollectStatistics = channel.unary_unary(
                '/openolt.Openolt/CollectStatistics',
                request_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.CreateTrafficSchedulers = channel.unary_unary(
                '/openolt.Openolt/CreateTrafficSchedulers',
                request_serializer=voltha__protos_dot_tech__profile__pb2.TrafficSchedulers.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.RemoveTrafficSchedulers = channel.unary_unary(
                '/openolt.Openolt/RemoveTrafficSchedulers',
                request_serializer=voltha__protos_dot_tech__profile__pb2.TrafficSchedulers.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.CreateTrafficQueues = channel.unary_unary(
                '/openolt.Openolt/CreateTrafficQueues',
                request_serializer=voltha__protos_dot_tech__profile__pb2.TrafficQueues.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.RemoveTrafficQueues = channel.unary_unary(
                '/openolt.Openolt/RemoveTrafficQueues',
                request_serializer=voltha__protos_dot_tech__profile__pb2.TrafficQueues.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.EnableIndication = channel.unary_stream(
                '/openolt.Openolt/EnableIndication',
                request_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Indication.FromString,
                )
        self.PerformGroupOperation = channel.unary_unary(
                '/openolt.Openolt/PerformGroupOperation',
                request_serializer=voltha__protos_dot_openolt__pb2.Group.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )
        self.GetExtValue = channel.unary_unary(
                '/openolt.Openolt/GetExtValue',
                request_serializer=voltha__protos_dot_openolt__pb2.ValueParam.SerializeToString,
                response_deserializer=voltha__protos_dot_common__pb2.ReturnValues.FromString,
                )
        self.OnuItuPonAlarmSet = channel.unary_unary(
                '/openolt.Openolt/OnuItuPonAlarmSet',
                request_serializer=voltha__protos_dot_openolt__pb2.OnuItuPonAlarm.SerializeToString,
                response_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                )


class OpenoltServicer(object):
    """Missing associated documentation comment in .proto file"""

    def DisableOlt(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReenableOlt(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActivateOnu(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeactivateOnu(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOnu(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OmciMsgOut(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnuPacketOut(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UplinkPacketOut(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FlowAdd(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FlowRemove(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HeartbeatCheck(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnablePonIf(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisablePonIf(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeviceInfo(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Reboot(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CollectStatistics(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTrafficSchedulers(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveTrafficSchedulers(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTrafficQueues(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveTrafficQueues(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableIndication(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PerformGroupOperation(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExtValue(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnuItuPonAlarmSet(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OpenoltServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DisableOlt': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableOlt,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'ReenableOlt': grpc.unary_unary_rpc_method_handler(
                    servicer.ReenableOlt,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'ActivateOnu': grpc.unary_unary_rpc_method_handler(
                    servicer.ActivateOnu,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Onu.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'DeactivateOnu': grpc.unary_unary_rpc_method_handler(
                    servicer.DeactivateOnu,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Onu.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'DeleteOnu': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOnu,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Onu.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'OmciMsgOut': grpc.unary_unary_rpc_method_handler(
                    servicer.OmciMsgOut,
                    request_deserializer=voltha__protos_dot_openolt__pb2.OmciMsg.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'OnuPacketOut': grpc.unary_unary_rpc_method_handler(
                    servicer.OnuPacketOut,
                    request_deserializer=voltha__protos_dot_openolt__pb2.OnuPacket.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'UplinkPacketOut': grpc.unary_unary_rpc_method_handler(
                    servicer.UplinkPacketOut,
                    request_deserializer=voltha__protos_dot_openolt__pb2.UplinkPacket.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'FlowAdd': grpc.unary_unary_rpc_method_handler(
                    servicer.FlowAdd,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Flow.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'FlowRemove': grpc.unary_unary_rpc_method_handler(
                    servicer.FlowRemove,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Flow.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'HeartbeatCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.HeartbeatCheck,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Heartbeat.SerializeToString,
            ),
            'EnablePonIf': grpc.unary_unary_rpc_method_handler(
                    servicer.EnablePonIf,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Interface.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'DisablePonIf': grpc.unary_unary_rpc_method_handler(
                    servicer.DisablePonIf,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Interface.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'GetDeviceInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeviceInfo,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.DeviceInfo.SerializeToString,
            ),
            'Reboot': grpc.unary_unary_rpc_method_handler(
                    servicer.Reboot,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'CollectStatistics': grpc.unary_unary_rpc_method_handler(
                    servicer.CollectStatistics,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'CreateTrafficSchedulers': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTrafficSchedulers,
                    request_deserializer=voltha__protos_dot_tech__profile__pb2.TrafficSchedulers.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'RemoveTrafficSchedulers': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveTrafficSchedulers,
                    request_deserializer=voltha__protos_dot_tech__profile__pb2.TrafficSchedulers.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'CreateTrafficQueues': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTrafficQueues,
                    request_deserializer=voltha__protos_dot_tech__profile__pb2.TrafficQueues.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'RemoveTrafficQueues': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveTrafficQueues,
                    request_deserializer=voltha__protos_dot_tech__profile__pb2.TrafficQueues.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'EnableIndication': grpc.unary_stream_rpc_method_handler(
                    servicer.EnableIndication,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Indication.SerializeToString,
            ),
            'PerformGroupOperation': grpc.unary_unary_rpc_method_handler(
                    servicer.PerformGroupOperation,
                    request_deserializer=voltha__protos_dot_openolt__pb2.Group.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
            'GetExtValue': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExtValue,
                    request_deserializer=voltha__protos_dot_openolt__pb2.ValueParam.FromString,
                    response_serializer=voltha__protos_dot_common__pb2.ReturnValues.SerializeToString,
            ),
            'OnuItuPonAlarmSet': grpc.unary_unary_rpc_method_handler(
                    servicer.OnuItuPonAlarmSet,
                    request_deserializer=voltha__protos_dot_openolt__pb2.OnuItuPonAlarm.FromString,
                    response_serializer=voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'openolt.Openolt', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Openolt(object):
    """Missing associated documentation comment in .proto file"""

    @staticmethod
    def DisableOlt(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/DisableOlt',
            voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReenableOlt(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/ReenableOlt',
            voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ActivateOnu(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/ActivateOnu',
            voltha__protos_dot_openolt__pb2.Onu.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeactivateOnu(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/DeactivateOnu',
            voltha__protos_dot_openolt__pb2.Onu.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOnu(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/DeleteOnu',
            voltha__protos_dot_openolt__pb2.Onu.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OmciMsgOut(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/OmciMsgOut',
            voltha__protos_dot_openolt__pb2.OmciMsg.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OnuPacketOut(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/OnuPacketOut',
            voltha__protos_dot_openolt__pb2.OnuPacket.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UplinkPacketOut(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/UplinkPacketOut',
            voltha__protos_dot_openolt__pb2.UplinkPacket.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FlowAdd(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/FlowAdd',
            voltha__protos_dot_openolt__pb2.Flow.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FlowRemove(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/FlowRemove',
            voltha__protos_dot_openolt__pb2.Flow.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def HeartbeatCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/HeartbeatCheck',
            voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            voltha__protos_dot_openolt__pb2.Heartbeat.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnablePonIf(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/EnablePonIf',
            voltha__protos_dot_openolt__pb2.Interface.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisablePonIf(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/DisablePonIf',
            voltha__protos_dot_openolt__pb2.Interface.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeviceInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/GetDeviceInfo',
            voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            voltha__protos_dot_openolt__pb2.DeviceInfo.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Reboot(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/Reboot',
            voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CollectStatistics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/CollectStatistics',
            voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateTrafficSchedulers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/CreateTrafficSchedulers',
            voltha__protos_dot_tech__profile__pb2.TrafficSchedulers.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveTrafficSchedulers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/RemoveTrafficSchedulers',
            voltha__protos_dot_tech__profile__pb2.TrafficSchedulers.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateTrafficQueues(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/CreateTrafficQueues',
            voltha__protos_dot_tech__profile__pb2.TrafficQueues.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveTrafficQueues(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/RemoveTrafficQueues',
            voltha__protos_dot_tech__profile__pb2.TrafficQueues.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableIndication(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/openolt.Openolt/EnableIndication',
            voltha__protos_dot_openolt__pb2.Empty.SerializeToString,
            voltha__protos_dot_openolt__pb2.Indication.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PerformGroupOperation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/PerformGroupOperation',
            voltha__protos_dot_openolt__pb2.Group.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExtValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/GetExtValue',
            voltha__protos_dot_openolt__pb2.ValueParam.SerializeToString,
            voltha__protos_dot_common__pb2.ReturnValues.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OnuItuPonAlarmSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openolt.Openolt/OnuItuPonAlarmSet',
            voltha__protos_dot_openolt__pb2.OnuItuPonAlarm.SerializeToString,
            voltha__protos_dot_openolt__pb2.Empty.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/health.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import meta_pb2 as voltha__protos_dot_meta__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/health.proto',
  package='voltha',
  syntax='proto3',
  serialized_options=b'\n\023org.opencord.volthaZ.github.com/opencord/voltha-protos/v3/go/voltha',
  serialized_pb=b'\n\x1avoltha_protos/health.proto\x12\x06voltha\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x18voltha_protos/meta.proto\"}\n\x0cHealthStatus\x12\x36\n\x05state\x18\x01 \x01(\x0e\x32 .voltha.HealthStatus.HealthStateB\x05\xe8\xf6\xcd\x1d\x01\"5\n\x0bHealthState\x12\x0b\n\x07HEALTHY\x10\x00\x12\x0e\n\nOVERLOADED\x10\x01\x12\t\n\x05\x44YING\x10\x02\x32\x61\n\rHealthService\x12P\n\x0fGetHealthStatus\x12\x16.google.protobuf.Empty\x1a\x14.voltha.HealthStatus\"\x0f\x82\xd3\xe4\x93\x02\t\x12\x07/healthBE\n\x13org.opencord.volthaZ.github.com/opencord/voltha-protos/v3/go/volthab\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,voltha__protos_dot_meta__pb2.DESCRIPTOR,])



_HEALTHSTATUS_HEALTHSTATE = _descriptor.EnumDescriptor(
  name='HealthState',
  full_name='voltha.HealthStatus.HealthState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HEALTHY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OVERLOADED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DYING', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=195,
  serialized_end=248,
)
_sym_db.RegisterEnumDescriptor(_HEALTHSTATUS_HEALTHSTATE)


_HEALTHSTATUS = _descriptor.Descriptor(
  name='HealthStatus',
  full_name='voltha.HealthStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='voltha.HealthStatus.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HEALTHSTATUS_HEALTHSTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=123,
  serialized_end=248,
)

_HEALTHSTATUS.fields_by_name['state'].enum_type = _HEALTHSTATUS_HEALTHSTATE
_HEALTHSTATUS_HEALTHSTATE.containing_type = _HEALTHSTATUS
DESCRIPTOR.message_types_by_name['HealthStatus'] = _HEALTHSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HealthStatus = _reflection.GeneratedProtocolMessageType('HealthStatus', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHSTATUS,
  '__module__' : 'voltha_protos.health_pb2'
  # @@protoc_insertion_point(class_scope:voltha.HealthStatus)
  })
_sym_db.RegisterMessage(HealthStatus)


DESCRIPTOR._options = None
_HEALTHSTATUS.fields_by_name['state']._options = None

_HEALTHSERVICE = _descriptor.ServiceDescriptor(
  name='HealthService',
  full_name='voltha.HealthService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=250,
  serialized_end=347,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetHealthStatus',
    full_name='voltha.HealthService.GetHealthStatus',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_HEALTHSTATUS,
    serialized_options=b'\202\323\344\223\002\t\022\007/health',
  ),
])
_sym_db.RegisterServiceDescriptor(_HEALTHSERVICE)

DESCRIPTOR.services_by_name['HealthService'] = _HEALTHSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/adapter.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import meta_pb2 as voltha__protos_dot_meta__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/adapter.proto',
  package='voltha',
  syntax='proto3',
  serialized_options=b'\n\023org.opencord.volthaB\rVolthaAdapterZ.github.com/opencord/voltha-protos/v3/go/voltha',
  serialized_pb=b'\n\x1bvoltha_protos/adapter.proto\x12\x06voltha\x1a\x19google/protobuf/any.proto\x1a\x1avoltha_protos/common.proto\x1a\x18voltha_protos/meta.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"@\n\rAdapterConfig\x12/\n\x11\x61\x64\x64itional_config\x18@ \x01(\x0b\x32\x14.google.protobuf.Any\"\xd2\x02\n\x07\x41\x64\x61pter\x12\x11\n\x02id\x18\x01 \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\x12\x15\n\x06vendor\x18\x02 \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\x12\x16\n\x07version\x18\x03 \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\x12%\n\x06\x63onfig\x18\x10 \x01(\x0b\x32\x15.voltha.AdapterConfig\x12;\n\x16\x61\x64\x64itional_description\x18@ \x01(\x0b\x32\x14.google.protobuf.AnyB\x05\xe8\xf6\xcd\x1d\x01\x12\x1a\n\x12logical_device_ids\x18\x04 \x03(\t\x12\x36\n\x12last_communication\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0e\x63urrentReplica\x18\x06 \x01(\x05\x12\x15\n\rtotalReplicas\x18\x07 \x01(\x05\x12\x10\n\x08\x65ndpoint\x18\x08 \x01(\t\x12\x0c\n\x04type\x18\t \x01(\t\"*\n\x08\x41\x64\x61pters\x12\x1e\n\x05items\x18\x01 \x03(\x0b\x32\x0f.voltha.AdapterBT\n\x13org.opencord.volthaB\rVolthaAdapterZ.github.com/opencord/voltha-protos/v3/go/volthab\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,voltha__protos_dot_common__pb2.DESCRIPTOR,voltha__protos_dot_meta__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_ADAPTERCONFIG = _descriptor.Descriptor(
  name='AdapterConfig',
  full_name='voltha.AdapterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='additional_config', full_name='voltha.AdapterConfig.additional_config', index=0,
      number=64, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=153,
  serialized_end=217,
)


_ADAPTER = _descriptor.Descriptor(
  name='Adapter',
  full_name='voltha.Adapter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.Adapter.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vendor', full_name='voltha.Adapter.vendor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='voltha.Adapter.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='voltha.Adapter.config', index=3,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='additional_description', full_name='voltha.Adapter.additional_description', index=4,
      number=64, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logical_device_ids', full_name='voltha.Adapter.logical_device_ids', index=5,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_communication', full_name='voltha.Adapter.last_communication', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currentReplica', full_name='voltha.Adapter.currentReplica', index=7,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalReplicas', full_name='voltha.Adapter.totalReplicas', index=8,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='voltha.Adapter.endpoint', index=9,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='voltha.Adapter.type', index=10,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=558,
)


_ADAPTERS = _descriptor.Descriptor(
  name='Adapters',
  full_name='voltha.Adapters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='voltha.Adapters.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=560,
  serialized_end=602,
)

_ADAPTERCONFIG.fields_by_name['additional_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_ADAPTER.fields_by_name['config'].message_type = _ADAPTERCONFIG
_ADAPTER.fields_by_name['additional_description'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_ADAPTER.fields_by_name['last_communication'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ADAPTERS.fields_by_name['items'].message_type = _ADAPTER
DESCRIPTOR.message_types_by_name['AdapterConfig'] = _ADAPTERCONFIG
DESCRIPTOR.message_types_by_name['Adapter'] = _ADAPTER
DESCRIPTOR.message_types_by_name['Adapters'] = _ADAPTERS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AdapterConfig = _reflection.GeneratedProtocolMessageType('AdapterConfig', (_message.Message,), {
  'DESCRIPTOR' : _ADAPTERCONFIG,
  '__module__' : 'voltha_protos.adapter_pb2'
  # @@protoc_insertion_point(class_scope:voltha.AdapterConfig)
  })
_sym_db.RegisterMessage(AdapterConfig)

Adapter = _reflection.GeneratedProtocolMessageType('Adapter', (_message.Message,), {
  'DESCRIPTOR' : _ADAPTER,
  '__module__' : 'voltha_protos.adapter_pb2'
  # @@protoc_insertion_point(class_scope:voltha.Adapter)
  })
_sym_db.RegisterMessage(Adapter)

Adapters = _reflection.GeneratedProtocolMessageType('Adapters', (_message.Message,), {
  'DESCRIPTOR' : _ADAPTERS,
  '__module__' : 'voltha_protos.adapter_pb2'
  # @@protoc_insertion_point(class_scope:voltha.Adapters)
  })
_sym_db.RegisterMessage(Adapters)


DESCRIPTOR._options = None
_ADAPTER.fields_by_name['id']._options = None
_ADAPTER.fields_by_name['vendor']._options = None
_ADAPTER.fields_by_name['version']._options = None
_ADAPTER.fields_by_name['additional_description']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/logical_device.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from voltha_protos import meta_pb2 as voltha__protos_dot_meta__pb2
from voltha_protos import openflow_13_pb2 as voltha__protos_dot_openflow__13__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/logical_device.proto',
  package='voltha',
  syntax='proto3',
  serialized_options=b'\n\023org.opencord.volthaB\017OFLogicalDeviceZ.github.com/opencord/voltha-protos/v3/go/voltha',
  serialized_pb=b'\n\"voltha_protos/logical_device.proto\x12\x06voltha\x1a\x1cgoogle/api/annotations.proto\x1a\x18voltha_protos/meta.proto\x1a\x1fvoltha_protos/openflow_13.proto\",\n\rLogicalPortId\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07port_id\x18\x02 \x01(\t\"\xb5\x01\n\x0bLogicalPort\x12\n\n\x02id\x18\x01 \x01(\t\x12\'\n\x08ofp_port\x18\x02 \x01(\x0b\x32\x15.openflow_13.ofp_port\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x16\n\x0e\x64\x65vice_port_no\x18\x04 \x01(\r\x12\x11\n\troot_port\x18\x05 \x01(\x08\x12\x33\n\x0eofp_port_stats\x18\x06 \x01(\x0b\x32\x1b.openflow_13.ofp_port_stats\"2\n\x0cLogicalPorts\x12\"\n\x05items\x18\x01 \x03(\x0b\x32\x13.voltha.LogicalPort\"\xe6\x02\n\rLogicalDevice\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x61tapath_id\x18\x02 \x01(\x04\x12#\n\x04\x64\x65sc\x18\x03 \x01(\x0b\x32\x15.openflow_13.ofp_desc\x12\x39\n\x0fswitch_features\x18\x04 \x01(\x0b\x32 .openflow_13.ofp_switch_features\x12\x16\n\x0eroot_device_id\x18\x05 \x01(\t\x12.\n\x05ports\x18\x80\x01 \x03(\x0b\x32\x13.voltha.LogicalPortB\t\xe2\xf6\xcd\x1d\x04\n\x02id\x12)\n\x05\x66lows\x18\x81\x01 \x01(\x0b\x32\x12.openflow_13.FlowsB\x05\xe2\xf6\xcd\x1d\x00\x12\x34\n\x0b\x66low_groups\x18\x82\x01 \x01(\x0b\x32\x17.openflow_13.FlowGroupsB\x05\xe2\xf6\xcd\x1d\x00\x12+\n\x06meters\x18\x83\x01 \x01(\x0b\x32\x13.openflow_13.MetersB\x05\xe2\xf6\xcd\x1d\x00\"6\n\x0eLogicalDevices\x12$\n\x05items\x18\x01 \x03(\x0b\x32\x15.voltha.LogicalDeviceBV\n\x13org.opencord.volthaB\x0fOFLogicalDeviceZ.github.com/opencord/voltha-protos/v3/go/volthab\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,voltha__protos_dot_meta__pb2.DESCRIPTOR,voltha__protos_dot_openflow__13__pb2.DESCRIPTOR,])




_LOGICALPORTID = _descriptor.Descriptor(
  name='LogicalPortId',
  full_name='voltha.LogicalPortId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.LogicalPortId.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_id', full_name='voltha.LogicalPortId.port_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=179,
)


_LOGICALPORT = _descriptor.Descriptor(
  name='LogicalPort',
  full_name='voltha.LogicalPort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.LogicalPort.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ofp_port', full_name='voltha.LogicalPort.ofp_port', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_id', full_name='voltha.LogicalPort.device_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_port_no', full_name='voltha.LogicalPort.device_port_no', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='root_port', full_name='voltha.LogicalPort.root_port', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ofp_port_stats', full_name='voltha.LogicalPort.ofp_port_stats', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=182,
  serialized_end=363,
)


_LOGICALPORTS = _descriptor.Descriptor(
  name='LogicalPorts',
  full_name='voltha.LogicalPorts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='voltha.LogicalPorts.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=365,
  serialized_end=415,
)


_LOGICALDEVICE = _descriptor.Descriptor(
  name='LogicalDevice',
  full_name='voltha.LogicalDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.LogicalDevice.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datapath_id', full_name='voltha.LogicalDevice.datapath_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='desc', full_name='voltha.LogicalDevice.desc', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='switch_features', full_name='voltha.LogicalDevice.switch_features', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='root_device_id', full_name='voltha.LogicalDevice.root_device_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ports', full_name='voltha.LogicalDevice.ports', index=5,
      number=128, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\004\n\002id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flows', full_name='voltha.LogicalDevice.flows', index=6,
      number=129, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\000', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flow_groups', full_name='voltha.LogicalDevice.flow_groups', index=7,
      number=130, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\000', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meters', full_name='voltha.LogicalDevice.meters', index=8,
      number=131, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\000', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=418,
  serialized_end=776,
)


_LOGICALDEVICES = _descriptor.Descriptor(
  name='LogicalDevices',
  full_name='voltha.LogicalDevices',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='voltha.LogicalDevices.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=778,
  serialized_end=832,
)

_LOGICALPORT.fields_by_name['ofp_port'].message_type = voltha__protos_dot_openflow__13__pb2._OFP_PORT
_LOGICALPORT.fields_by_name['ofp_port_stats'].message_type = voltha__protos_dot_openflow__13__pb2._OFP_PORT_STATS
_LOGICALPORTS.fields_by_name['items'].message_type = _LOGICALPORT
_LOGICALDEVICE.fields_by_name['desc'].message_type = voltha__protos_dot_openflow__13__pb2._OFP_DESC
_LOGICALDEVICE.fields_by_name['switch_features'].message_type = voltha__protos_dot_openflow__13__pb2._OFP_SWITCH_FEATURES
_LOGICALDEVICE.fields_by_name['ports'].message_type = _LOGICALPORT
_LOGICALDEVICE.fields_by_name['flows'].message_type = voltha__protos_dot_openflow__13__pb2._FLOWS
_LOGICALDEVICE.fields_by_name['flow_groups'].message_type = voltha__protos_dot_openflow__13__pb2._FLOWGROUPS
_LOGICALDEVICE.fields_by_name['meters'].message_type = voltha__protos_dot_openflow__13__pb2._METERS
_LOGICALDEVICES.fields_by_name['items'].message_type = _LOGICALDEVICE
DESCRIPTOR.message_types_by_name['LogicalPortId'] = _LOGICALPORTID
DESCRIPTOR.message_types_by_name['LogicalPort'] = _LOGICALPORT
DESCRIPTOR.message_types_by_name['LogicalPorts'] = _LOGICALPORTS
DESCRIPTOR.message_types_by_name['LogicalDevice'] = _LOGICALDEVICE
DESCRIPTOR.message_types_by_name['LogicalDevices'] = _LOGICALDEVICES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LogicalPortId = _reflection.GeneratedProtocolMessageType('LogicalPortId', (_message.Message,), {
  'DESCRIPTOR' : _LOGICALPORTID,
  '__module__' : 'voltha_protos.logical_device_pb2'
  # @@protoc_insertion_point(class_scope:voltha.LogicalPortId)
  })
_sym_db.RegisterMessage(LogicalPortId)

LogicalPort = _reflection.GeneratedProtocolMessageType('LogicalPort', (_message.Message,), {
  'DESCRIPTOR' : _LOGICALPORT,
  '__module__' : 'voltha_protos.logical_device_pb2'
  # @@protoc_insertion_point(class_scope:voltha.LogicalPort)
  })
_sym_db.RegisterMessage(LogicalPort)

LogicalPorts = _reflection.GeneratedProtocolMessageType('LogicalPorts', (_message.Message,), {
  'DESCRIPTOR' : _LOGICALPORTS,
  '__module__' : 'voltha_protos.logical_device_pb2'
  # @@protoc_insertion_point(class_scope:voltha.LogicalPorts)
  })
_sym_db.RegisterMessage(LogicalPorts)

LogicalDevice = _reflection.GeneratedProtocolMessageType('LogicalDevice', (_message.Message,), {
  'DESCRIPTOR' : _LOGICALDEVICE,
  '__module__' : 'voltha_protos.logical_device_pb2'
  # @@protoc_insertion_point(class_scope:voltha.LogicalDevice)
  })
_sym_db.RegisterMessage(LogicalDevice)

LogicalDevices = _reflection.GeneratedProtocolMessageType('LogicalDevices', (_message.Message,), {
  'DESCRIPTOR' : _LOGICALDEVICES,
  '__module__' : 'voltha_protos.logical_device_pb2'
  # @@protoc_insertion_point(class_scope:voltha.LogicalDevices)
  })
_sym_db.RegisterMessage(LogicalDevices)


DESCRIPTOR._options = None
_LOGICALDEVICE.fields_by_name['ports']._options = None
_LOGICALDEVICE.fields_by_name['flows']._options = None
_LOGICALDEVICE.fields_by_name['flow_groups']._options = None
_LOGICALDEVICE.fields_by_name['meters']._options = None
# @@protoc_insertion_point(module_scope)
